==> emp_agents-0.1.2.post1-py3-none-any.whl: emp_agents/tools/twitter/__init__.py <==
from typing import Annotated

from typing_extensions import Doc

from emp_agents.models.protocol import SkillSet, tool_method

from .actions import make_poll, make_tweet, make_tweet_with_image, reply_to_tweet


class TwitterSkill(SkillSet):
    """
    Skill for interacting with Twitter API
    """

    @tool_method
    async def make_tweet(
        content: Annotated[str, Doc("The content of the tweet to be made.")]
    ) -> str:
        """Make a tweet"""
        return await make_tweet(content)

    @tool_method
    async def make_tweet_with_image(
        content: Annotated[str, Doc("The content of the tweet to be made.")]
    ) -> str:
        """Make a tweet with an image"""
        return await make_tweet_with_image(content)

    @tool_method
    async def make_poll(
        content: Annotated[str, Doc("The content of the tweet to be made.")],
        options: Annotated[
            str, Doc("The options for the poll, as a comma separated list")
        ],
        duration_minutes: Annotated[
            int, Doc("The duration of the poll in minutes, defaults to 1")
        ] = 1,
    ) -> str:
        """Make a poll"""
        options = options.lstrip("[").rstrip("]")
        return await make_poll(
            content,
            duration_minutes,
            [option.strip() for option in options.split(",")],
        )

    @tool_method
    async def reply_to_tweet(
        tweet_id: Annotated[int, Doc("The ID of the tweet to reply to.")],
        content: Annotated[str, Doc("The content of the tweet to be made.")],
    ) -> str:
        """Reply to a tweet"""
        return await reply_to_tweet(tweet_id, content)

==> emp_agents-0.3.2-py3-none-any.whl: emp_agents/tools/twitter/__init__.py <==
from typing import Annotated

from typing_extensions import Doc

from emp_agents.models.protocol import SkillSet, tool_method

from .actions import make_poll, make_tweet, make_tweet_with_image, reply_to_tweet


class TwitterSkill(SkillSet):
    """
    Skill for interacting with Twitter API
    """

    @tool_method
    @staticmethod
    async def make_tweet(
        content: Annotated[str, Doc("The content of the tweet to be made.")],
    ) -> str:
        """Make a tweet"""
        return await make_tweet(content)

    @tool_method
    @staticmethod
    async def make_tweet_with_image(
        content: Annotated[str, Doc("The content of the tweet to be made.")],
        image_url: Annotated[str, Doc("The URL of the image to be uploaded.")],
    ) -> str:
        """Make a tweet with an image"""
        return await make_tweet_with_image(content, image_url)

    @tool_method
    @staticmethod
    async def make_poll(
        content: Annotated[str, Doc("The content of the tweet to be made.")],
        options: Annotated[
            str, Doc("The options for the poll, as a comma separated list")
        ],
        duration_minutes: Annotated[
            int, Doc("The duration of the poll in minutes, defaults to 1")
        ] = 1,
    ) -> str:
        """Make a poll"""
        options = options.lstrip("[").rstrip("]")
        return await make_poll(
            content,
            duration_minutes,
            [option.strip() for option in options.split(",")],
        )

    @tool_method
    @staticmethod
    async def reply_to_tweet(
        tweet_id: Annotated[int, Doc("The ID of the tweet to reply to.")],
        content: Annotated[str, Doc("The content of the tweet to be made.")],
    ) -> str:
        """Reply to a tweet"""
        return await reply_to_tweet(tweet_id, content)
